import OHeader from '@/components/o-header'
import OPopup from '@/components/o-popup'
import OSticky from '@/components/o-sticky'
import { Button, Cell, CellGroup, Field } from 'vant'
import { defineComponent, reactive } from 'vue'
import styles from '../index.module.less'
import StudentList from '../modal/student-list'
import SubjectList from '../modal/subject-list'
import TeacherList from '../modal/teacher-list'

export default defineComponent({
  name: 'create-orchestra',
  setup() {
    const state = reactive({
      subjectStatus: false,
      studentStatus: false,
      teacherStatus: false
    })

    const onSubmit = () => {
      state.teacherStatus = true
    }

    return () => (
      <div class={styles['create-orchestra']}>
        <OHeader />

        <CellGroup inset>
          <Field label="乐团名称" placeholder="请输入乐团名称" inputAlign="right" maxlength={30} />
          <Field
            label="乐团声部"
            readonly
            placeholder="选择声部"
            isLink
            inputAlign="right"
            onClick={() => (state.subjectStatus = true)}
          />

          {[1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 7, 8, 9, 10].map((item: any) => (
            <Cell title="长笛" isLink onClick={() => (state.studentStatus = true)}>
              {{
                value: () => (
                  <>
                    已选 <span style={{ color: 'var(--van-primary-color)' }}>{item + 1}</span>
                    名学生
                  </>
                )
              }}
            </Cell>
          ))}
        </CellGroup>

        <OSticky position="bottom">
          <div class={['btnGroup']}>
            <Button type="primary" block round onClick={onSubmit}>
              下一步
            </Button>
          </div>
        </OSticky>

        {/* 选择声部 */}
        <OPopup v-model:modelValue={state.subjectStatus} style="background: #F8F8F8;">
          <SubjectList onClose={() => (state.subjectStatus = false)} />
        </OPopup>

        {/* 选择学生 */}
        <OPopup v-model:modelValue={state.studentStatus} style="background: #f8f8f8;">
          <StudentList onClose={() => (state.studentStatus = false)} />
        </OPopup>

        {/* 选择老师 */}
        <OPopup v-model:modelValue={state.teacherStatus} style="background: #f8f8f8;">
          <TeacherList onClose={() => (state.teacherStatus = false)} />
        </OPopup>
      </div>
    )
  }
})
