import OSticky from '@/components/o-sticky'
import { Button, Cell, CellGroup, Checkbox, CheckboxGroup, Icon, Image, Tag } from 'vant'
import { defineComponent, reactive } from 'vue'
import styles from '../index.module.less'
import radioCheck from '@/common/images/icon-radio-check.png'
import radioDefault from '@/common/images/icon-radio-default.png'
import { useRouter } from 'vue-router'

export default defineComponent({
  name: 'payment',
  emits: ['next'],
  setup() {
    const router = useRouter()
    const state = reactive({
      check: ['in'],
      checkboxRefs: [] as any
    })

    const onSelect = (type: string) => {
      state.checkboxRefs[type].toggle()
    }

    // 购买
    const onSubmit = () => {
      router.push('/orderDetail')
    }
    return () => (
      <>
        <div class={styles.applyTitle}>报名须知</div>
        <div class={[styles.paymentTips, styles.mlr13]}>
          <p>1、您注册时所选择的乐团声部，即为乐团录取最终确认的声部，请您务必仔细填写；</p>
          <p>
            2、所有参与乐团的学生免费赠送选报声部教材，教材随乐器一同发放，若您自备乐器，则需承担教材运费。
          </p>
        </div>

        <CheckboxGroup v-model={state.check} style={{ paddingBottom: '20px' }}>
          <div class={styles.applyTitle}>乐器</div>
          <CellGroup
            inset
            class={[styles.mlr13, styles.sectionCell]}
            onClick={() => onSelect('in')}
          >
            <Cell border={false}>
              {{
                icon: () => (
                  <Checkbox
                    name="in"
                    class={styles.checkbox}
                    ref={(el: any) => (state.checkboxRefs['in'] = el)}
                    v-slots={{
                      icon: (props: any) => (
                        <Icon
                          class={styles.iconChecked}
                          name={props.checked ? radioCheck : radioDefault}
                        />
                      )
                    }}
                  />
                ),
                title: () => (
                  <div class={styles.section}>
                    <Image
                      class={styles.img}
                      src="https://daya.ks3-cn-beijing.ksyuncs.com/12/1670231208704.png"
                    />
                    <div class={styles.sectionContent}>
                      <h2>长笛标准配置</h2>
                      <Tag type="primary">品牌型号</Tag>
                      <p class={styles.model}>含笛头、笛身、笛尾、擦拭布、节拍器、谱架</p>
                    </div>
                  </div>
                )
              }}
            </Cell>
            <Cell>
              {{
                title: () => (
                  <div class={styles.extra}>
                    <div class={styles.sectionPrice}>
                      <p class={styles.price}>
                        新团特惠：<span>¥3,860</span>
                      </p>
                      <p class={styles.originPrice}>
                        原价：<del>¥3,580.00</del>
                      </p>
                    </div>
                    <div class={styles.sectionTips}>赠价值500元乐器维保服务一年</div>
                  </div>
                )
              }}
            </Cell>
          </CellGroup>

          <div class={styles.applyTitle}>教材</div>
          <CellGroup
            inset
            class={[styles.mlr13, styles.sectionCell]}
            onClick={() => onSelect('teaching')}
          >
            <Cell border={false}>
              {{
                icon: () => (
                  <Checkbox
                    name="teaching"
                    class={styles.checkbox}
                    ref={(el: any) => (state.checkboxRefs['teaching'] = el)}
                    v-slots={{
                      icon: (props: any) => (
                        <Icon
                          class={styles.iconChecked}
                          name={props.checked ? radioCheck : radioDefault}
                        />
                      )
                    }}
                  />
                ),
                title: () => (
                  <div class={styles.section}>
                    <Image
                      class={styles.img}
                      src="https://daya.ks3-cn-beijing.ksyuncs.com/12/1670231208704.png"
                    />
                    <div class={styles.sectionContent}>
                      <h2>大雅金唐教材</h2>
                      <Tag type="primary">品牌型号</Tag>
                      <p class={styles.model}>含笛头、笛身、笛尾、擦拭布、节拍器、谱架</p>
                    </div>
                  </div>
                )
              }}
            </Cell>
            <Cell>
              {{
                title: () => (
                  <div class={styles.extra}>
                    <div class={styles.sectionPrice}>
                      <p class={styles.price}>
                        新团特惠：<span class={styles.free}>免费赠送</span>
                      </p>
                      <p class={styles.originPrice}>
                        原价：<del>¥3,580.00</del>
                      </p>
                    </div>
                  </div>
                )
              }}
            </Cell>
          </CellGroup>

          <div class={styles.applyTitle}>乐团学习系统</div>
          <CellGroup
            inset
            class={[styles.mlr13, styles.sectionCell]}
            onClick={() => onSelect('system')}
          >
            <Cell border={false}>
              {{
                icon: () => (
                  <Checkbox
                    name="system"
                    class={styles.checkbox}
                    ref={(el: any) => (state.checkboxRefs['system'] = el)}
                    v-slots={{
                      icon: (props: any) => (
                        <Icon
                          class={styles.iconChecked}
                          name={props.checked ? radioCheck : radioDefault}
                        />
                      )
                    }}
                  />
                ),
                title: () => (
                  <div class={styles.section}>
                    <Image
                      class={styles.img}
                      src="https://daya.ks3-cn-beijing.ksyuncs.com/12/1670231208704.png"
                    />
                    <div class={styles.sectionContent}>
                      <h2>团练宝</h2>
                      <Tag type="primary">6个月</Tag>
                      <p class={styles.model}>含乐团课件、课后训练、乐器练习、云教练等</p>
                    </div>
                  </div>
                )
              }}
            </Cell>
            <Cell>
              {{
                title: () => (
                  <div class={styles.extra}>
                    <div class={styles.sectionPrice}>
                      <p class={styles.price}>
                        新团特惠：<span>¥1,380.00</span>
                      </p>
                      <p class={styles.originPrice}>
                        原价：<del>¥3,580.00</del>
                      </p>
                    </div>
                  </div>
                )
              }}
            </Cell>
          </CellGroup>
        </CheckboxGroup>

        <OSticky position="bottom" background="white">
          <div class={styles.paymentContainer}>
            <div class={styles.payemntPrice}>
              <p class={styles.needPrice}>
                支付金额：<span>¥3,860.00</span>
              </p>
              <p class={styles.allPrice}>
                总原价：<del>¥3,580.00</del>
              </p>
            </div>
            <div class={styles.paymentBtn}>
              <Button
                color="linear-gradient(135deg, #FF8C4A 0%, #FF531C 100%)"
                round
                onClick={onSubmit}
              >
                立即购买
              </Button>
            </div>
          </div>
        </OSticky>
      </>
    )
  }
})
